@@ -4,7 +4,7 @@ import logging
 import os
 import pkg_resources
 
-from .baseclass import ndpoly, FeatureNotSupported, INDETERMINANT_DEFAULTS
+from .baseclass import ndpoly, FeatureNotSupported
 
 from .align import (
     align_polynomials,
@@ -16,7 +16,6 @@ from .align import (
 from .construct import (
     polynomial,
     aspolynomial,
-    bindex,
     clean_attributes,
     polynomial_from_attributes,
     monomial,
@@ -26,6 +25,14 @@ from .sympy_ import to_sympy
 
 from .array_function import *
 from .poly_function import *
+from .utils import (
+    bindex,
+    cross_truncate,
+    glexindex,
+    glexsort,
+)
+from .option import get_options, set_options, global_options
+
 
 def get_version(name):
     """
