@@ -3,5 +3,5 @@ from .polynomial import polynomial
 from .aspolynomial import aspolynomial
 from .clean import clean_attributes
 from .from_attributes import polynomial_from_attributes
-from .monomial import monomial, bindex
+from .monomial import monomial
 from .symbols import symbols
